/*
    *
    * This file is a part of CoreShot.
    * A screen capture utility for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/


#include <QFile>
#include <QTimer>
#include <QDateTime>
#include <QFileDialog>
#include <QClipboard>

#include <cprime/cprime.h>
#include <cprime/appopenfunc.h>

#include "coreshotdialog.h"
#include "coreshot.h"
#include "ui_coreshot.h"


coreshot::coreshot(QWidget *parent) : QWidget(parent), ui(new Ui::coreshot)
{
    ui->setupUi(this);

    loadSettings();
    startSetup();

    files = "";
}

coreshot::~coreshot()
{
    delete ui;
}
/**
 * @brief Setup ui elements
 */
void coreshot::startSetup()
{
    // set window size
    if (touch) {
        this->setWindowState(Qt::WindowMaximized);
    } else {
        this->resize(800, 500);
    }
}

/**
 * @brief Loads application settings
 */
void coreshot::loadSettings()
{
    //touch mode
    touch = sm->value("CoreApps", "TouchMode");
    saveLocation = QString(sm->value("CoreShot", "SaveLocation"));
}


void coreshot::setPixmap(QPixmap &pix)
{
    ui->shotPreview->setOriginalPixmap(pix);
}

void coreshot::on_save_clicked()
{
    QString fileName = saveLocation;
    fileName = CPrime::ValidityFunc::checkIsValidDir(fileName);

    if (fileName.count()) {
        QFile file(fileName + "/Screenshot_" + QDateTime::currentDateTime().toString("yyyy-MM-dd_hh-mm-ss") + ".png");
        ui->shotPreview->originalPixmap().save(&file, "PNG");
        file.close();
        files = fileName;
        // Function from utilities.cpp
        CPrime::InfoFunc::messageEngine("Screenshot is saved", CPrime::MessageType::Info, this);

        this->hide();
        // Based on Message engine time how it will stay
        QTimer::singleShot(1000, this, SLOT(close()));
    } else {
        CPrime::InfoFunc::messageEngine("Screenshot is not saved\nPlease select a valid directory from CoreGarage.", CPrime::MessageType::Warning, this);
        return;
    }
}

void coreshot::on_saveAs_clicked()
{
    QString filename = QFileDialog::getSaveFileName(this, tr("Save Screenshot"), saveLocation, tr("Image (*.png)"));
    QFile file(filename + ".png");

    ui->shotPreview->originalPixmap().save(&file, "PNG");

    file.close();
    files = filename;
    // Function from utilities.cpp
    CPrime::InfoFunc::messageEngine("Screenshot Saved", CPrime::MessageType::Info, this);

    this->hide();
    // Based on Message engine time how it will stay
    QTimer::singleShot(1000, this, SLOT(close()));
}

void coreshot::on_cancel_clicked()
{
    this->close();
}

void coreshot::on_newShot_clicked()
{
    coreshotdialog *shotD = new coreshotdialog();
    shotD->show();
    this->close();
}

void coreshot::on_openInEditor_clicked()
{
    QString fileName = saveLocation;
    fileName = CPrime::ValidityFunc::checkIsValidDir(fileName);

    if (!fileName.count()) {
        CPrime::InfoFunc::messageEngine("Save directory does not exist\nPlease select a valid directory from CoreGarage.", CPrime::MessageType::Warning, this);
        return;
    }

    fileName = saveLocation + "/Screenshot_" + QDateTime::currentDateTime().toString("yyyy-MM-dd_hh-mm-ss") + ".png";
    QFile file(fileName);
    ui->shotPreview->originalPixmap().save(&file, "PNG");
    file.close();
    files = fileName;

    CPrime::AppOpenFunc::defaultAppEngine(CPrime::Category::ImageEditor, files, this);
    this->close();
}

void coreshot::on_copyTo_clicked()
{
    QClipboard *clip = QApplication::clipboard();
    clip->setPixmap(ui->shotPreview->originalPixmap());
    this->close();
}
